==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebFilteringStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringStrategyDescription } from "./WebFilteringStrategyDescription";
/**
 * @hidden
 */
export let WebFilteringStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringStrategyDescriptionMetadata.a == null) {
                WebFilteringStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringStrategyDescriptionMetadata.c(WebFilteringStrategyDescriptionMetadata.a);
            }
            if (a.k(WebFilteringStrategyDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebFilteringStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebFilteringStrategyDescriptionMetadata.b(a);
            a.ad("WebFilteringStrategy", () => new WebFilteringStrategyDescription());
            a.ac("WebFilteringStrategy", WebFilteringStrategyDescriptionMetadata.a);
        }
    }
    WebFilteringStrategyDescriptionMetadata.$t = markType(WebFilteringStrategyDescriptionMetadata, 'WebFilteringStrategyDescriptionMetadata');
    WebFilteringStrategyDescriptionMetadata.a = null;
    return WebFilteringStrategyDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebFilteringStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringStrategyDescription } from "./WebFilteringStrategyDescription";
/**
 * @hidden
 */
export let WebFilteringStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringStrategyDescriptionMetadata.a == null) {
                WebFilteringStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringStrategyDescriptionMetadata.c(WebFilteringStrategyDescriptionMetadata.a);
            }
            if (a.k(WebFilteringStrategyDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFilteringStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebFilteringStrategyDescriptionMetadata.b(a);
            a.ae("WebFilteringStrategy", () => new WebFilteringStrategyDescription());
            a.ad("WebFilteringStrategy", WebFilteringStrategyDescriptionMetadata.a);
        }
    }
    WebFilteringStrategyDescriptionMetadata.$t = markType(WebFilteringStrategyDescriptionMetadata, 'WebFilteringStrategyDescriptionMetadata');
    WebFilteringStrategyDescriptionMetadata.a = null;
    return WebFilteringStrategyDescriptionMetadata;
})();
